@@ -382,7 +382,7 @@ def Clip_Dataset_GDAL(input_name, output_name, latlim, lonlim):
 
     return()
 
-def clip_data(input_file, latlim, lonlim, band = 1):
+def clip_data(input_file, latlim, lonlim, epsg_clip = 4326, band = 1):
     """
     Clip the data to the defined extend of the user (latlim, lonlim) or to the
     extend of the DEM tile
@@ -402,6 +402,17 @@ def clip_data(input_file, latlim, lonlim, band = 1):
 
     # Open Array
     data_in = dest_in.GetRasterBand(band).ReadAsArray()
+    Proj_out = Get_epsg(dest_in)
+    
+    if Proj_out != epsg_clip:
+     
+        inProj = Proj(init='epsg:%d' %epsg_clip)
+        outProj = Proj(init='epsg:%d' %Proj_out)
+    
+        # Up to here, all  the projection have been defined, as well as a
+        # transformation from the from to the to
+        lonlim[0], latlim[0] = transform(inProj,outProj,lonlim[0], latlim[0])
+        lonlim[1], latlim[1] = transform(inProj,outProj,lonlim[1], latlim[1])       
 
     # Define the array that must remain
     Geo_in = dest_in.GetGeoTransform()
@@ -417,12 +428,12 @@ def clip_data(input_file, latlim, lonlim, band = 1):
     Geo_in[3] = Geo_in[3] + Start_y * Geo_in[5]
     Geo_out = tuple(Geo_in)
 
-    data = np.zeros([End_y - Start_y, End_x - Start_x])
+    data = np.ones([End_y - Start_y, End_x - Start_x])*np.nan
 
     data = data_in[Start_y:End_y,Start_x:End_x]
     dest_in = None
 
-    return(data, Geo_out)
+    return(data, Geo_out, Proj_out)
 
 def clip_data_shp(input_file, shp_filename, IDname = "OBJECTID", number_shp = 1, band = 1):
     """
@@ -795,6 +806,24 @@ def reproject_dataset_example(dataset, dataset_example, method=1):
         gdal.ReprojectImage(g, dest1, wgs84.ExportToWkt(), osng.ExportToWkt(), gdal.GRA_Lanczos)
     if method == 4:
         gdal.ReprojectImage(g, dest1, wgs84.ExportToWkt(), osng.ExportToWkt(), gdal.GRA_Average)
+    if method == 5:
+        gdal.ReprojectImage(g, dest1, wgs84.ExportToWkt(), osng.ExportToWkt(), gdal.GRA_Cubic)
+    if method == 6:
+        gdal.ReprojectImage(g, dest1, wgs84.ExportToWkt(), osng.ExportToWkt(), gdal.GRA_CubicSpline)
+    if method == 7:
+        gdal.ReprojectImage(g, dest1, wgs84.ExportToWkt(), osng.ExportToWkt(), gdal.GRA_Mode)
+    if method == 8:
+        gdal.ReprojectImage(g, dest1, wgs84.ExportToWkt(), osng.ExportToWkt(), gdal.GRA_Max)
+    if method == 9:
+        gdal.ReprojectImage(g, dest1, wgs84.ExportToWkt(), osng.ExportToWkt(), gdal.GRA_Min)
+    if method == 10:
+        gdal.ReprojectImage(g, dest1, wgs84.ExportToWkt(), osng.ExportToWkt(), gdal.GRA_Med)
+    if method == 11:
+        gdal.ReprojectImage(g, dest1, wgs84.ExportToWkt(), osng.ExportToWkt(), gdal.GRA_Q1)
+    if method == 12:
+        gdal.ReprojectImage(g, dest1, wgs84.ExportToWkt(), osng.ExportToWkt(), gdal.GRA_Q3)
+    if method == 13:
+        gdal.ReprojectImage(g, dest1, wgs84.ExportToWkt(), osng.ExportToWkt(), gdal.GRA_Sum)
         
     return(dest1)
 
